Edi
===

Simple and elegant Slack bot.

[![build status](https://travis-ci.org/jreese/edi.svg?branch=master)](https://travis-ci.org/jreese/edi)
[![version](https://img.shields.io/pypi/v/edi-slack.svg)](https://pypi.org/project/edi-slack)
[![license](https://img.shields.io/pypi/l/edi-slack.svg)](https://github.com/jreese/edi/blob/master/LICENSE)
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


License
-------

Edi is copyright [John Reese][], and licensed under the MIT license.
I am providing code in this repository to you under an open source license.
Because this is my personal repository, the license you receive to my code
is from me and not from my employer.
See the ``LICENSE`` file for details.

[John Reese]: https://jreese.sh
